﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.IO;

namespace StudentKeeper
{
    public partial class StudentForm : Form
    {
        private BindingList<Student> students;

        public StudentForm()
        {
            InitializeComponent();
            readStudentsFromFile();
        }

        private void readStudentsFromFile()
        {
            students = new BindingList<Student>();

            if (File.Exists("students.txt"))
            {
                //read from it
                StreamReader reader = new StreamReader("students.txt");

                //string allOfFile = reader.ReadToEnd();
                //string[] lines = allOfFile.Split("\n".ToCharArray());

                while (!reader.EndOfStream)
                {
                    Student student = new Student();
                    student.name =  reader.ReadLine();
                    student.major = reader.ReadLine();
                    student.homeTown = reader.ReadLine();

                    students.Add(student);
                }
                reader.Close();
            }
            cboStudents.DataSource = students;

            updateStudentCount();
            
        }

        private void updateStudentCount()
        {
            lblStudentCount.Text = students.Count.ToString();
        }

        private void writeStudentsToFile()
        {
            StreamWriter writer = new StreamWriter("students.txt");

            foreach (Student student in students)
            {
                writer.WriteLine(student.name);
                writer.WriteLine(student.major);
                writer.WriteLine(student.homeTown);
            }
            writer.Close();
        }

        private void btnAddStudent_Click(object sender, EventArgs e)
        {
            if (txtName.Text != "")
            {
                Student newStudent = new Student();
                newStudent.name = txtName.Text;
                newStudent.major = txtMajor.Text;
                newStudent.homeTown = txtHomeTown.Text;

                txtName.Text = "";
                txtMajor.Text = "";
                txtHomeTown.Text = "";

                students.Add(newStudent);
                updateStudentCount();

                writeStudentsToFile();
            }
        }

        private void StudentForm_Load(object sender, EventArgs e)
        {
        }

        private void btnDeleteStudent_Click(object sender, EventArgs e)
        {
            if (students.Count > 0)
            {
                //find out what was selected
                //delete it from the student list
                students.RemoveAt(cboStudents.SelectedIndex);

                //update the count on the UI
                updateStudentCount();

                //save the list to file
                writeStudentsToFile();

                ////update the combo box
                //cboStudents.DataSource = null;
                //cboStudents.DataSource = students;
            }
        }

        private void cboStudents_SelectedIndexChanged(object sender, EventArgs e)
        {
            Student selectedStudent = students[cboStudents.SelectedIndex];
            txtEditName.Text = selectedStudent.name;
            txtEditMajor.Text = selectedStudent.major;
            txtEditHometown.Text = selectedStudent.homeTown;      
        }

        private void btnSaveEditedStudent_Click(object sender, EventArgs e)
        {
            Student selectedStudent = students[cboStudents.SelectedIndex];
            selectedStudent.name = txtEditName.Text;
            selectedStudent.major = txtEditMajor.Text;
            selectedStudent.homeTown = txtEditHometown.Text;

            

            writeStudentsToFile();

        }

        protected override bool ProcessCmdKey(ref Message msg, Keys keyData)
        {
            if (keyData == Keys.Up)
            {
                btnAddStudent.BackColor = Color.Blue;
            }
            else if (keyData == Keys.Down)
            {
                btnAddStudent.BackColor = Color.Green;
            }
            else if (keyData == Keys.Left)
            {
                btnAddStudent.BackColor = Color.Red;
            }
            else if (keyData == Keys.Right)
            {
                btnAddStudent.BackColor = Color.White;
            }

            return false;
        }

    }
}
